@@ -31,3 +31,8 @@ option.flags = function() {
       (typeof val === 'boolean' ? '' : '=' + val);
   });
 };
+
+// Get all option keys
+option.keys = function() {
+  return Object.keys(data);
+};
